==> consumer-center-api-1.2.0-20170309.065528-1-sources.jar: cn/com/duiba/consumer/center/api/dto/ConsumerSignInfoDto.java <==
package cn.com.duiba.consumer.center.api.dto;

import java.io.Serializable;

/**
 * Created by liuyao on 2016/12/13.
 */
public class ConsumerSignInfoDto implements Serializable {

    private static final long serialVersionUID = 4168430074071750832L;

    private Boolean canSign;//是否可以签到
    private Integer signType;//签到策略
    private Integer credits = 0;//本次签到可以添加的分数(自定义签到不返回此字段)
    private Integer nextCredits = 0;//下次签到的积分(自定义签到不返回此字段)
    private String signInfoUrl;
    private Integer signDay;//当前连续签到的天数

    private Boolean configError = false;//签到系统的配置是否完整,没有完整即为false

    public Boolean getConfigError() {
        return configError;
    }

    public void setConfigError(Boolean configError) {
        this.configError = configError;
    }

    public Integer getNextCredits() {
        return nextCredits;
    }

    public void setNextCredits(Integer nextCredits) {
        this.nextCredits = nextCredits;
    }

    public Boolean getCanSign() {
        return canSign;
    }

    public void setCanSign(Boolean canSign) {
        this.canSign = canSign;
    }

    public Integer getSignType() {
        return signType;
    }

    public void setSignType(Integer signType) {
        this.signType = signType;
    }

    public Integer getCredits() {
        return credits;
    }

    public void setCredits(Integer credits) {
        this.credits = credits;
    }

    public String getSignInfoUrl() {
        return signInfoUrl;
    }

    public void setSignInfoUrl(String signInfoUrl) {
        this.signInfoUrl = signInfoUrl;
    }

    public Integer getSignDay() {
        return signDay;
    }

    public void setSignDay(Integer signDay) {
        this.signDay = signDay;
    }
}

==> consumer-center-api-1.2.8-20170619.111654-1-sources.jar: cn/com/duiba/consumer/center/api/dto/ConsumerSignInfoDto.java <==
package cn.com.duiba.consumer.center.api.dto;

import java.io.Serializable;

/**
 * Created by liuyao on 2016/12/13.
 */
public class ConsumerSignInfoDto implements Serializable {

    private static final long serialVersionUID = 4168430074071750832L;

    private Boolean canSign;//是否可以签到
    private Integer signType;//签到策略
    private Integer credits = 0;//本次签到可以添加的分数(自定义签到不返回此字段)
    private Integer nextCredits = 0;//下次签到的积分(自定义签到不返回此字段)
    private String signInfoUrl;
    private Integer signDay;//当前连续签到的天数
    private Integer signCycle;

    private Boolean configError = false;//签到系统的配置是否完整,没有完整即为false

    public Boolean getConfigError() {
        return configError;
    }

    public void setConfigError(Boolean configError) {
        this.configError = configError;
    }

    public Integer getNextCredits() {
        return nextCredits;
    }

    public void setNextCredits(Integer nextCredits) {
        this.nextCredits = nextCredits;
    }

    public Boolean getCanSign() {
        return canSign;
    }

    public void setCanSign(Boolean canSign) {
        this.canSign = canSign;
    }

    public Integer getSignType() {
        return signType;
    }

    public void setSignType(Integer signType) {
        this.signType = signType;
    }

    public Integer getCredits() {
        return credits;
    }

    public void setCredits(Integer credits) {
        this.credits = credits;
    }

    public String getSignInfoUrl() {
        return signInfoUrl;
    }

    public void setSignInfoUrl(String signInfoUrl) {
        this.signInfoUrl = signInfoUrl;
    }

    public Integer getSignDay() {
        return signDay;
    }

    public void setSignDay(Integer signDay) {
        this.signDay = signDay;
    }

    public Integer getSignCycle() {
        return signCycle;
    }

    public void setSignCycle(Integer signCycle) {
        this.signCycle = signCycle;
    }
}
